Struct schemadb::SchemaBatch[][src]

pub struct SchemaBatch { /* fields omitted */ }
SchemaBatch holds a collection of updates that can be applied to a DB atomically. The updates will be applied in the order in which they are added to the SchemaBatch.

Implementations

Creates an empty batch.

Adds an insert/update operation to the batch.

Adds a delete operation to the batch.