pub struct SchemaBatch { /* fields omitted */ }
SchemaBatch holds a collection of updates that can be applied to a DB atomically. The updates
will be applied in the order in which they are added to the SchemaBatch.
Adds an insert/update operation to the batch.
Adds a delete operation to the batch.
Formats the value using the given formatter. Read more
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,